function StructureForData = DataConstFileSWU2011Q2
% DataConstFileSWU2011Q2: Shows how the data construction output should be provided for YADA.
%
% USAGE:
%
%       StructureForData = DataConstFileSWU2011Q2
%
% where StructureForData is a proper structure in matlab. The file is run in matlab via the eval
% function.
%
% INPUTS:          None!
%
% REQUIRED OUTPUT: StructureForData (structure). Any name for this structure will do since YADA renames it internally.
%                  REQUIRED FIELDS:  Y.data              (nxT) data-matrix of the n observable variables that should be evaluated by the
%                                                        Kalman filter
%                                    X.data              (kxT) data-matrix with exogenous data, may be an empty matrix, but must be stated
%                                    Y.names             (n dimensional cellstring) with variable names
%                                    X.names             (k dimensional cellstring) with names for exogenous variables (may be empty)
%                                    sample              (1x4 matrix) containing [start-year start-period end-yer end-period]. Must match
%                                                        the number of observations T.
%                                    frequency           (string) data frequency. Valid entries are: a(nnual), q(uarterly), m(onthly)
%                                                        if invalid frequency is reported, it is set to annual with sample being set
%                                                        to [1 1 T 1]
%                  OPTIONAL FIELDS:  Lambda              (vector) with lambda values to use for the DSGE-VAR models.
%                                    Y.levels            (1xn) vector, where 0 indicates a first differenced variable and 1 a levels
%                                                        variable
%                                    Y.annual            (1xn) vector, where 1 indicates that the variable should be annualized based
%                                                        on the data frequency, while 0 means that it should not be annualized (i.e.,
%                                                        can already be regarded as annualized).
%
% NOTE: and many more fields are supported.
%
%
% NOTICE:
%         * Any valid matlab functions on the path can be used by the function. How you transform any data you read in from
%           a spreadsheet, text file, of matlab mat-file is up to you.
%         * Any file format supported by matlab can be used for your data.
%
%
%
%                       Written by: Anders Warne
%                                   New Area Wide Model Project
%                                   DG-R/EMO
%                                   European Central Bank (ECB)
%                                   Email: anders.warne@ecb.europa.eu
%                                   Copyright  2006-2017 European Central Bank.
%
%                       First version: August 19, 2011.
%                        This version: July 18, 2017.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% LICENSE INFORMATION:
%
%      YADA is free software: you can redistribute it and/or modify
%      it under the terms of the GNU General Public License as published by
%      the Free Software Foundation, either version 3 of the License, or
%      (at your option) any later version.
%
%      This program is distributed in the hope that it will be useful,
%      but WITHOUT ANY WARRANTY; without even the implied warranty of
%      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%      GNU General Public License for more details.
%
%      You should have received a copy of the GNU General Public License
%      along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%      YADA is released under the GNU General Public License, Version 3,
%      29 June 2007 <http://www.gnu.org/licenses/>. The current release of
%      the program was last modified by the ECB on the "This version" date
%      above.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% CHANGELOG:
%
% * 07-12-2011: The function now reads real-time data.
%
% * 11-10-2016: The function now reads actuals and is updated for the McAdam-Warne project.
%
% * 12-10-2016: Continued with the editing and testing of the function.
%
% * 27-01-2017: Taking into account that unemployment and the interest rate have data points
%               for 2001Q1.
%
% * 18-05-2017: The function now supports the RTD vintage 2002Q1.
%
% * 29-05-2017: The function now supports the RTD vintage 2003Q1.
%
% * 06-06-2017: The function now supports the RTD vintage 2004Q1.
%
% * 14-06-2017: The function now supports the RTD vintage 2005Q1.
%
% * 22-06-2017: The function now supports the RTD vintage 2006Q1.
%
% * 26-06-2017: The function now supports the RTD vintages 2007Q1-2011Q1.
%
% * 18-07-2017: The function now supports the 2011Q2 vintage.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
% Read data from a file. Make sure that the full path is given since this file will be moved
% into the sub-driectory tmp of pwd (pwd = working directory, i.e. the directory where YADA.m
% is located)
%
EAData = xlsread([pwd '/example/McAdamWarne/data/RTDB-AWM-2011Q2.xls']);
%
% check if the user has MS office with excel. If true then the first row of EAData
% doesn't have any NaN's
%
if isnan(EAData(1,1))==1;
   if isnan(EAData(2,1))==1;
      EAData = EAData(:,2:size(EAData,2));
   elseif isnan(EAData(1,2))==1;
      EAData = EAData(2:size(EAData,1),:);
   end;
end;
T = size(EAData,1);
%
Y = [100*diff(log(EAData(:,1:6))) EAData(2:T,7:8)];
T = size(Y,1);
%
% make sure we use real wages instead of nominal
%
Y(:,6) = Y(:,6)-Y(:,4);
%
% add 3 years of unobserved data
%
Y = [Y;NaN*ones(11,8)];
%
% transpose the data since YADA prefers it that way
%
StructureForData.Y.data = Y';
StructureForData.Y.names = {'DY' 'DC' 'DI' 'PIY' 'DE' 'DW' 'U' 'R'};
StructureForData.Lambda = [0.25 0.5 0.75 1 1.25 1.5 1.75 2 2.5 3 3.5 4 4.5 5 6 7 8 9 10 25 Inf];
StructureForData.Y.levels = [0 0 0 1 0 1 1 1];
StructureForData.Y.annual = [1 1 1 0 1 0 0 0];
StructureForData.Y.annualscale = [1 1 1 1 1 1 1 1 1];
StructureForData.X.data = ones(1,T+11);
StructureForData.X.extradata = ones(1,120);
StructureForData.X.names = {'const'};
StructureForData.sample = [1980 1 2014 1];
StructureForData.frequency = 'q';
StructureForData.percentiles = [2.5 5 15 25 75 85 95 97.5];
%
% now load data for actuals
%
ActualsData = xlsread([pwd '/example/McAdamWarne/data/RTDB-AWM-TrueValues-AnnualRevision.xls']);
%
% check if the user has MS office with excel. If true then the first row of ActualsData
% doesn't have any NaN's
%
if isnan(ActualsData(1,1))==1;
	if isnan(ActualsData(1,2))==1;
      ActualsData = ActualsData(2:size(ActualsData,1),:)
   elseif isnan(ActualsData(2,1))==1;
   	ActualsData = ActualsData(:,2:size(ActualsData,2));
   end;
end;
%disp(size(ActualsData))
Tstar = size(ActualsData,1);
ActualsData = [Y(1:T-2,:);ActualsData(42:Tstar,1:8)];
%disp(Y(T-2:T+2,:))
%disp(ActualsData(T-2:T+2,:))
%
% add output information about the actuals
%
StructureForData.Y.actuals.data = ActualsData';
StructureForData.Y.actuals.title = 'Annual revision';

%
% end of DataConstFileSWU2011Q2.m
%
